@@ -148,3 +148,13 @@ class PREFIX:
         CLOUD = "viso_cloud/mqtt"
 
         DEBUG = "viso_debug/mqtt"
+
+
+# ----- [MQTT & REDIS] ----------------------------------------------------------
+
+AVAILABLE_METADATA_MODES = ["mqtt", "redis"]
+
+
+class MetaDataMODE:
+    MQTT = "mqtt"
+    REDIS = "redis"
