@@ -1,8 +1,8 @@
-
 class Module:
     """
         modules container mqtt and redis ports as individual
     """
+
     class Region:
         type = 'region-of-interest'
 
@@ -29,6 +29,7 @@ class Module:
     """
         modules publish metadata in redis string together
     """
+
     class Roi:
         type = 'roi'
 
@@ -48,3 +49,19 @@ class Module:
 
     class FrameViewer:
         type = "frame-viewer"
+
+    """
+        modules which has v2 UI
+    """
+
+    class VFVideoFile:
+        type = "video-feed-video-file"
+
+    class VFIpCamera:
+        type = "video-feed-ip-camera"
+
+    class VFUsbCamera:
+        type = "video-feed-usb-camera"
+
+    class VideoViewer:
+        type = "video-view"
